==> mysql-5.7.36.tar.gz: mysql-5.7.36/storage/ndb/clusterj/clusterj-api/src/main/java/com/mysql/clusterj/Transaction.java <==
/*
   Copyright (c) 2010, 2021, Oracle and/or its affiliates.
   All rights reserved. Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj;

/** Transaction represents a user transaction active in the cluster.
 *
 */
public interface Transaction {

    /** Begin a transaction.
     * 
     */
    void begin();

    /** Commit a transaction.
     * 
     */
    void commit();

    /** Roll back a transaction.
     * 
     */
    void rollback();

    /** Is there a transaction currently active?
     * @return true if a transaction is active
     */
    boolean isActive();

    /** Mark this transaction as rollback only. After this method is called,
     * commit() will roll back the transaction and throw an exception;
     * rollback() will roll back the transaction and not throw an exception.
     */
    void setRollbackOnly();

    /** Has this transaction been marked for rollback only?
     * @return true if the transaction has been marked for rollback only
     */
    boolean getRollbackOnly();

}

==> mysql-8.4_8.4.7.orig.tar.gz: mysql-8.4.7/storage/ndb/clusterj/clusterj-api/src/main/java/com/mysql/clusterj/Transaction.java <==
/*
   Copyright (c) 2010, 2025, Oracle and/or its affiliates.
   Use is subject to license terms.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.clusterj;

/** Transaction represents a user transaction active in the cluster.
 *
 */
public interface Transaction {

    /** Begin a transaction.
     * 
     */
    void begin();

    /** Commit a transaction.
     * 
     */
    void commit();

    /** Roll back a transaction.
     * 
     */
    void rollback();

    /** Is there a transaction currently active?
     * @return true if a transaction is active
     */
    boolean isActive();

    /** Mark this transaction as rollback only. After this method is called,
     * commit() will roll back the transaction and throw an exception;
     * rollback() will roll back the transaction and not throw an exception.
     */
    void setRollbackOnly();

    /** Has this transaction been marked for rollback only?
     * @return true if the transaction has been marked for rollback only
     */
    boolean getRollbackOnly();

}
